==> apache-nuttx-12.0.0.tar.gz: nuttx/mm/kmm_heap/kmm_memdump.c <==
/****************************************************************************
 * mm/kmm_heap/kmm_memdump.c
 *
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.  The
 * ASF licenses this file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the
 * License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the
 * License for the specific language governing permissions and limitations
 * under the License.
 *
 ****************************************************************************/

/****************************************************************************
 * Included Files
 ****************************************************************************/

#include <nuttx/config.h>
#include <nuttx/mm/mm.h>

#ifdef CONFIG_MM_KERNEL_HEAP

/****************************************************************************
 * Public Functions
 ****************************************************************************/

/****************************************************************************
 * Name: kmm_memdump
 *
 * Description:
 *   Dump the memory block allocated by this task
 *
 ****************************************************************************/

void kmm_memdump(pid_t pid)
{
  mm_memdump(g_kmmheap, pid);
}

#endif /* CONFIG_MM_KERNEL_HEAP */

==> apache-nuttx-12.2.1.tar.gz: nuttx/mm/kmm_heap/kmm_memdump.c <==
/****************************************************************************
 * mm/kmm_heap/kmm_memdump.c
 *
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.  The
 * ASF licenses this file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the
 * License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the
 * License for the specific language governing permissions and limitations
 * under the License.
 *
 ****************************************************************************/

/****************************************************************************
 * Included Files
 ****************************************************************************/

#include <nuttx/config.h>
#include <nuttx/mm/mm.h>

#ifdef CONFIG_MM_KERNEL_HEAP

/****************************************************************************
 * Public Functions
 ****************************************************************************/

/****************************************************************************
 * Name: kmm_memdump
 *
 * Description:
 *   Dump the memory block allocated by this task
 *
 ****************************************************************************/

void kmm_memdump(FAR const struct mm_memdump_s *dump)
{
  mm_memdump(g_kmmheap, dump);
}

#endif /* CONFIG_MM_KERNEL_HEAP */
